      SUBROUTINE LPIFFR
*.
*...LPIFFR   Define FFREAD data cards for LP
*.
*. SEQUENCE  : GCCUTS GCPHYS
*.           : LPCGEO LPFLAG RCREP  XECGEO XECINT AIST
*. CALLS     : FFKEY  GMITMD xxIFFR
*. CALLED    : UGINIT
*.
*. BANKS L   : None
*. BANKS U   : None
*.
*. AUTHOR    : T.Mashimo
*. VERSION   : 1.18
*. CREATED   : 06-May-00
*. LAST MOD  : 18-Aug-03
*.
*. Modification Log.
*. 18-Aug-03   K.Ozone         (V1.18) Changed RISETIME, DECAYTIME, GAIN,
*.                             THRESHOLD, TCUT, and BINSIZE to
*.                             TDCPARS(1-6), respecively.
*. 10-Jul-03   R.Sawada        (V1.17) Added XENDST.
*. 10-Jun-03   K.Ozone         (V1.16) Default value of NTUPLE is 0 to 1.
*. 09-Jun-03   K.Ozone         (V1.15) DSTSW(6)=5 -> COSMON,
*.                             DSTSW(6)=6 -> ALPHON.
*. 04-Jun-03   R.Sawada        (V1.14) QREFON = 1 as default value.
*.                             QRFIDX chnaged 1.49 to 1.58.
*. 18-Apr-03   R.Sawada        (V1.13) Added FILLON and changed FILL
*.                             to LEVEL.
*. 14-Mar-03   R.Sawada        (V1.12) Added RISETIME, DECAYTIME, GAIN,
*.                             THRESHOLD.
*. 25-Jan-03   R.Sawada        (V1.11) Added DPTMON.
*. 22-Jan-03   R.Sawada        (V1.10) Added HCRLON, GASXEON, GASTEMP, 
*.                             GASPRES, HCX, HCY, and ZXEEXP.
*. 20-Jul-02   K.Ozone         (V1.09) Changed default value of QABSON
*.                             to 1.
*. 15-Jul-02   K.Ozone         (V1.08) Changed 'temporary' initial value
*.                             of PMTQEF.
*. 05-Jul-02   K.Ozone         (V1.07) added some switches;
*.                             QABSON, SUMOUT, NPEOUT, DEPOUT, EXPOUT
*.                             DST*, and *HNAM.
*.                             TERAS parameters put together into AIST
*.                             (See V1.06).
*.                             Removed BSC*.
*.                             Added PMTQEF as QE of R6041Q.
*.                             Added inclusion of "xecpmt.inc".
*. 31-Mar-02   K.Ozone         (V1.06) added data cards for AISTCG
*.                             ELCE0: Mean of electron beam energy
*.                             ELCAD: electron beam angular divergence
*.                             ELCD : bunch size of electron beam
*.                             PHTE1: Energy of incidental photon at
*.                                    laboratory frame in MeV
*.                             COLD : Distance between collision point
*.                                    and 2nd collimator in m
*.                             COLR : Radius of the 2nd collimator in m
*. 20-Mar-02   K.Ozone         (V1.05) Changed BSCON definition;
*.                             a) BSCON=1; E dist. is read from RZ file,
*.                             b) BSCON=2; E dist obeys the simple formula,
*.                             c) BSCON=0; flat distribution,
*.                             and added BSCRZ, that is the RZ file name,
*.                             and BSCHID which is histo-ID in BSCRZ
*. 08-Mar-02   K.Ozone         (V1.04) BSCON; Back Scattered Compton gamma
*.                             switch
*. 04-Sep-01   W.Ootani        (V1.03) FILL(filling factor of liquid Xe) 
*. 22-May-00   T.Mashimo       (V1.02) LPITMD -> GMITMD.
*. 16-May-00   T.Mashimo       (V1.01) Call LPITMD and BFIFFR.
*. 06-May-00   T.Mashimo       (V1.00) First version.
*.
*.**********************************************************************
*.
#include "declare.inc"
#include "geant321/gccuts.inc"
#include "geant321/gcphys.inc"
#include "gmmatm.inc"
#include "gctmpa.inc"
#include "lpflag.inc"
#include "lpcgeo.inc"
#include "xecgeo.inc"
#include "xecint.inc"
#include "rcrep.inc"
#include "aistcg.inc"
#include "xecpmt.inc"
#include "tdcpar.inc"
*
*--
*--
*-- Set up default parameters
*--
*--
*
*
*-- Set up sensible defaults for physics mechanisms in GEANT
*-- (original default values are set by GINIT)
*
      IPAIR = 1
      ICOMP = 1
      IPHOT = 1
      IPFIS = 0
      IDRAY = 1
      IANNI = 1
      IBREM = 1
      IHADR = 1
      IMUNU = 1
      IDCAY = 1
      ILOSS = 1
      IMULS = 1
*
*-- Change default kinetic energy cut values set by GINIT
*
      CUTGAM = 1.00E-5   ! 10keV cut
      CUTELE = 1.00E-5
      CUTNEU = 1.00E-5
      CUTHAD = 1.00E-5
      CUTMUO = 1.00E-5
*
*-- Cut for DESTEP to be used for generating scintillation photons
*
      CUTDES = 0.0
*
*-- Momentum cut for GSXYZ in GUSTEP (in MeV)
*
      CUTXYZ = 0.0
*
*-- Initialize other parameters
*
      LUNHBK = 10
      LUNPS  = 11
      LUNREP = 6
      NTUPON = 1
      SUMOUT = 1
      NPEOUT = 1
      EXPOUT = 0
      DEPOUT = 0
      DPTMON = 0
      FILLON = 0
      COSMON = 0
      ALPHON = 0
      CALL VBLANK(LHBNAM, NAMLWO)
      CALL VBLANK(LPSNAM, NAMLWO)
*
      NXPMT  = 6
      NYPMT  = 6
      NZPMT  = 8
      PMTINT = 6.2
*
*-- Initialize momentum range in MeV/c
*-- (it makes no sense?)
*
      MOMTM(1) = 0.0
      MOMTM(2) = 40.0

*-- Xenon level factor. (In 1st-LP, LEVEL = 0.960080645)
      LEVEL = 1.02

*-- position realistic honeycomb core
      HCRLON = 0

*-- alpha position
      PALPHA = 18.9

*-- gas xenon
      GASXEON = 0
      GASTEMP = -80.0
      GASPRES = 1.70

*-- center of realistic honeycomb core
      HCX = 0.
      HCY = 0.

*-- distance of between honeycomb and holder
      ZXEEXP = 0.

*-- x,y,z,theta,phi,momentum distribution
      CALL VBLANK(DSTSW, 6)
      CALL VBLANK(XHNAM, NAMLWO)
      CALL VBLANK(YHNAM, NAMLWO)
      CALL VBLANK(ZHNAM, NAMLWO)
      CALL VBLANK(THNAM, NAMLWO)
      CALL VBLANK(PHNAM, NAMLWO)
      CALL VBLANK(MHNAM, NAMLWO)
      CALL VBLANK(DSTHID, 6)

*-- TERAS and gamma beam configurations
      ELCE0 = 764.0D0
      ELCAD = 0.15D-3
      ELCD  = 2D-3
      PHTE1 = 4.68D-6
      COLD  = 11.4D0
      COLR  = 1D-3

*-- switch for reflection on quartz window and ref. index
      XENDST = 1
      QREFON = 1
      QRFIDX = 1.58

*-- switch for absorption on quartz window
      QABSON = 1

*-- QE which includes Collection efficiency
*   It is set to 0.0631 as initial value in xsinit.F if AQBSON = 1.
*   Otherwise, set to 0.05.
*   Here the value is, however, set to 0.00 by a techinical reason.
      PMTQEF = 0.0

*-- for tdc simulation
      TDCOUT = 0
      DATA TDCPARS /
     +     2.5E-9, 10.0E-9, 5.0E6, -10.0, 30.0E-9, 25.0E-12 /

*
*--
*-- Define our FFREAD data cards
*--
*
      CALL FFKEY('NPMT',   NXPMT,  3, 'INTEGER')    ! total number of PMTs
      CALL FFKEY('PMTINT', PMTINT, 1, 'REAL')       ! interval distance beween PMTs
      CALL FFKEY('CUTDES', CUTDES, 1, 'REAL')       ! cut-off energy for scintillation photons
      CALL FFKEY('CUTXYZ', CUTXYZ, 1, 'REAL')       ! momentum threshold in meta-file in MeV/c
*
      CALL FFKEY('HIST',   LHBNAM,  NAMLWO, 'MIXED') ! file name of output ntuple
      CALL FFKEY('META',   LPSNAM,  NAMLWO, 'MIXED') ! file name of output meta-file
      CALL FFKEY('NTUPLE', NTUPON,  1, 'INTEGER')    ! switch of ntuple output
      CALL FFKEY('SUMOUT', SUMOUT,  1, 'INTEGER')    ! switch of various sums
      CALL FFKEY('NPEOUT', NPEOUT,  1, 'INTEGER')    ! switch of Npe observed by each PMT
      CALL FFKEY('EXPOUT', EXPOUT,  1, 'INTEGER')    ! switch of experiment variables
      CALL FFKEY('DEPOUT', DEPOUT,  1, 'INTEGER')    ! switch of NDEPO and XDEPOS(0,3000)
      CALL FFKEY('DPTMON', DPTMON,  1, 'INTEGER')    ! switch of deposit time infomation
      CALL FFKEY('TDCOUT', TDCOUT,  1, 'INTEGER')    ! switch of TDC simulation
      CALL FFKEY('TDCPAR', TDCPARS, 6, 'REAL')       ! TDC simulation parameters
*
*-- additional keys
      CALL FFKEY('LEVEL',  LEVEL,  1, 'REAL')       ! Xe surface level for 1st LP
      CALL FFKEY('HCRLON', HCRLON, 1, 'INTEGER')    ! realistic honeycomb core
      CALL FFKEY('FILLON', FILLON, 1, 'INTEGER')    ! filler at the back of PMT
      CALL FFKEY('COSMON', COSMON, 1, 'INTEGER')    ! cosmic-ray muon mode
      CALL FFKEY('ALPHON', ALPHON, 1, 'INTEGER')    ! alpha particle mode
      CALL FFKEY('GASXEON',GASXEON,1, 'INTEGER')    ! gas xenon
      CALL FFKEY('GASTEMP',GASTEMP,1, 'REAL')       ! gas temperature
      CALL FFKEY('GASPRES',GASPRES,1, 'REAL')       ! gas pressure
      CALL FFKEY('XENDST', XENDST, 1, 'INTEGER')    ! switch of Xe 'n' distribution
      CALL FFKEY('QREFON', QREFON, 1, 'INTEGER')    ! reflection on quartz
      CALL FFKEY('QRFIDX', QRFIDX, 1, 'REAL')       ! refractive index of quartz
      CALL FFKEY('QABSON', QABSON, 1, 'INTEGER')    ! absorption on quartz
      CALL FFKEY('PMTQEF', PMTQEF, 1, 'REAL')       ! average Q.E. of R6041Q
*
      CALL FFKEY('HCX', HCX, 1, 'REAL')             ! center position of realistic honeycomb in X
      CALL FFKEY('HCY', HCY, 1, 'REAL')             ! center position of realistic honeycomb in Y
*
      CALL FFKEY('ZXEEXP', ZXEEXP, 1, 'REAL')       ! honeycomb-to-holder distance
*
      CALL FFKEY('MOMTM',  MOMTM,  2, 'REAL')       ! momentum range of incident beam
*
      CALL FFKEY('DSTSW',  DSTSW,  6, 'INTEGER')    ! distribution of (x,y,z,theta,phi,|p|)
      CALL FFKEY('DSTHID', DSTHID, 6, 'INTEGER')    ! histogram ID of (x,y,z,theta,phi,|p|)
      CALL FFKEY('XHNAM',  XHNAM,  NAMLWO, 'MIXED') ! file name of x-dist histogram
      CALL FFKEY('YHNAM',  YHNAM,  NAMLWO, 'MIXED') ! file name of y-dist histogram
      CALL FFKEY('ZHNAM',  ZHNAM,  NAMLWO, 'MIXED') ! file name of z-dist histogram
      CALL FFKEY('THNAM',  THNAM,  NAMLWO, 'MIXED') ! file name of theta-dist histogram
      CALL FFKEY('PHNAM',  PHNAM,  NAMLWO, 'MIXED') ! file name of phi-dist histogram
      CALL FFKEY('MHNAM',  MHNAM,  NAMLWO, 'MIXED') ! file name of |p|-dist histogram
*
      CALL FFKEY('AIST',   ELCE0,  6, 'REAL')       ! TERAS beam parameters
*
*-- Initialize parameters and define FFREAD data cards
*-- related to magnetic field and tracking medium parameters.
*
      CALL GMITMD
      CALL BFIFFR
*
*-- Define FFREAD data cards for individual detector components
*
      CALL XSIFFR
*
*-- Allow user to define private data cards
*
      CALL USIFFR
*
  999 CONTINUE
      RETURN
      END
